==> _private_core_network-1.3.42.tar.gz: lib/network_resources/auth/repo.dart <==
import 'package:_private_core_network/network_resources/resources.dart';
import 'package:dio/dio.dart';
import 'app_api.dart';
import 'models/auth_industry.dart';

class AuthXRepo {
  AuthXRepo._();

  static AuthXRepo? _instance;

  factory AuthXRepo([MyAppApi? api]) {
    _instance ??= AuthXRepo._();
    _instance!._api = api ?? MyAppApiImp();
    return _instance!;
  }

  late MyAppApi _api;

  Future<NetworkResponse> resetPasswordByEmail(params) async {
    return await _api.resetPasswordByEmail(params);
  }

  Future<ConfirmOtp?> confirmResetProPasswordCode(params) async {
    NetworkResponse response = await _api.confirmResetProPasswordCode(params);
    return response.data;
  }

  Future<bool> updateNewProPasswordByToken(params) async {
    NetworkResponse response = await _api.updateNewProPasswordByToken(params);
    return response.data;
  }

  Future<UpdateInfoResult> checkUpdateEmail(params) async {
    NetworkResponse response = await _api.checkUpdateEmail(params);
    return response.data ?? UpdateInfoResult(status: false);
  }

  Future<ConfirmOtp?> confirmResetUserPasswordCode(params) async {
    NetworkResponse response = await _api.confirmResetUserPasswordCode(params);
    return response.data;
  }

  Future<bool> updateNewUserPasswordByToken(params) async {
    NetworkResponse response = await _api.updateNewUserPasswordByToken(params);
    return response.data;
  }

  Future<String?> setThumbnailForUserOrPro(image, filePath,
      [ProgressCallback? callback]) async {
    NetworkResponse response =
        await _api.setThumbnailForUserOrPro(image, filePath, callback);
    return response.data;
  }

  Future<ProInfo?> getProInfo([params]) async {
    NetworkResponse response = await _api.getProInfo(params);
    return response.data;
  }

  Future<UserModel?> getUserInfo([params]) async {
    NetworkResponse response = await _api.getUserInfo(params);
    return response.data;
  }

  Future<List<AuthIndustry>> getServiceCatForIndustry([params]) async {
    NetworkResponse response = await _api.getServiceCatForIndustry(params);
    return response.data ?? [];
  }

  Future loginTerminal({required params}) async {
    return await _api.loginTerminal(params);
  }

  Future<NetworkResponse> loginUserOrProByUsername(params) async {
    return await _api.loginUserOrProByUsername(params);
  }

  Future<TokenResponseLogin?> refreshToken(String refreshToken) async {
    NetworkResponse response = await _api.refreshToken(refreshToken);
    return response.data;
  }
}

==> _private_core_network-1.3.48.tar.gz: lib/network_resources/auth/repo.dart <==
import 'package:_private_core_network/network_resources/resources.dart';
import 'package:dio/dio.dart';
import '../model/username_available_result.dart';
import 'app_api.dart';
import 'models/auth_industry.dart';
import 'models/check_email_result.dart';
import 'models/upload_thumbnail_result.dart';

class AuthXRepo {
  AuthXRepo._();

  static AuthXRepo? _instance;

  factory AuthXRepo([MyAppApi? api]) {
    _instance ??= AuthXRepo._();
    _instance!._api = api ?? MyAppApiImp();
    return _instance!;
  }

  late MyAppApi _api;

  Future<NetworkResponse> resetPasswordByEmail(params) async {
    return await _api.resetPasswordByEmail(params);
  }

  Future<ConfirmOtp?> confirmResetProPasswordCode(params) async {
    NetworkResponse response = await _api.confirmResetProPasswordCode(params);
    return response.data;
  }

  Future<bool> updateNewProPasswordByToken(params) async {
    NetworkResponse response = await _api.updateNewProPasswordByToken(params);
    return response.data;
  }

  Future<UpdateInfoResult> checkUpdateEmail(params) async {
    NetworkResponse response = await _api.checkUpdateEmail(params);
    return response.data ?? UpdateInfoResult(status: false);
  }

  Future<ConfirmOtp?> confirmResetUserPasswordCode(params) async {
    NetworkResponse response = await _api.confirmResetUserPasswordCode(params);
    return response.data;
  }

  Future<bool> updateNewUserPasswordByToken(params) async {
    NetworkResponse response = await _api.updateNewUserPasswordByToken(params);
    return response.data;
  }

  Future<UploadThumbnalResult?> setThumbnailForUserOrPro(image, filePath,
      [ProgressCallback? callback]) async {
    NetworkResponse response =
        await _api.setThumbnailForUserOrPro(image, filePath, callback);
    return response.data;
  }

  Future<ProInfo?> getProInfo([params]) async {
    NetworkResponse response = await _api.getProInfo(params);
    return response.data;
  }

  Future<UserModel?> getUserInfo([params]) async {
    NetworkResponse response = await _api.getUserInfo(params);
    return response.data;
  }

  Future<List<AuthIndustry>> getServiceCatForIndustry([params]) async {
    NetworkResponse response = await _api.getServiceCatForIndustry(params);
    return response.data ?? [];
  }

  Future loginTerminal({required params}) async {
    return await _api.loginTerminal(params);
  }

  Future<NetworkResponse> loginUserOrProByUsername(params) async {
    return await _api.loginUserOrProByUsername(params);
  }

  Future<TokenResponseLogin?> refreshToken(String refreshToken) async {
    NetworkResponse response = await _api.refreshToken(refreshToken);
    return response.data;
  }

  Future<CheckEmailResult?> checkNewProEmail(params) async {
    NetworkResponse response = await _api.checkNewProEmail(params);
    return response.data;
  }

  Future<ConfirmOtp?> confirmNewProCode(params) async {
    NetworkResponse response = await _api.confirmNewProCode(params);
    return response.data;
  }

  Future<UsernameAvailableResult?> checkUsernameAvailable(params) async {
    NetworkResponse response = await _api.checkUsernameAvailable(params);
    return response.data;
  }

  Future<TokenResponseLogin?> createNewPro(params) async {
    NetworkResponse response = await _api.createNewPro(params);
    return response.data;
  }

  Future<TokenResponseLogin?> createNewUser(params) async {
    NetworkResponse response = await _api.createNewUser(params);
    return response.data;
  }

  Future<bool> updateRegistrationLevelForUser(params) async {
    NetworkResponse response =
        await _api.updateRegistrationLevelForUser(params);
    return response.data ?? false;
  }

  Future<bool> updateRegistrationLevelForPro(params) async {
    NetworkResponse response = await _api.updateRegistrationLevelForPro(params);
    return response.data ?? false;
  }
}
